# coding: utf-8

"""
    Mentortools Deep Agent API

    FastAPI service for running Mentortools deep agent

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ChatMessageAttachmentType(str, Enum):
    """
    Attachment type enum for chat messages.
    """

    """
    allowed enum values
    """
    IMAGE = 'IMAGE'
    VIDEO = 'VIDEO'
    AUDIO = 'AUDIO'
    ATTACHMENT = 'ATTACHMENT'

    @classmethod
    def from_json(cls, json_str: str) -> ChatMessageAttachmentType:
        """Create an instance of ChatMessageAttachmentType from a JSON string"""
        return ChatMessageAttachmentType(json.loads(json_str))


